skhubness.analysis.VALID_HUBNESS_MEASURES — scikit-hubness 0.21.0 documentation

# skhubness.analysis.VALID_HUBNESS_MEASURES

`skhubness.analysis.` `VALID_HUBNESS_MEASURES` = ['all', 'k_skewness', 'k_skewness_truncnorm', 'atkinson', 'gini', 'robinhood', 'antihubs', 'antihub_occurrence', 'hubs', 'hub_occurrence', 'groupie_ratio', 'k_neighbors', 'k_occurrence']

  Built-in mutable sequence.

  If no argument is given, the constructor creates a new empty list. The argument must be an iterable if specified.